@@ -52,20 +52,16 @@ class Iterator(object):
         similar to the dict.values() method, this will only return the selected fields
         in a tuple
 
-        return -- generator -- each iteration will return just the field values in
+        return -- ValueIterator -- each iteration will return just the field values in
             the order they were selected, if you only selected one field, than just that field
             will be returned, if you selected multiple fields than a tuple of the fields in
             the order you selected them will be returned
         """
-        field_names = self.query.fields_select
-        fcount = len(field_names)
-        if fcount:
-            for x in self.results:
-                field_vals = [x.get(fn, None) for fn in field_names]
-                yield field_vals if fcount > 1 else field_vals[0]
-
-        else:
-            raise ValueError("no select fields were set, so cannot iterate values")
+        return ValueIterator(
+            results=self.results,
+            has_more=self.has_more,
+            query=self.query
+        )
 
     def __iter__(self):
         self.reset()
@@ -97,6 +93,22 @@ class Iterator(object):
         return r
 
 
+class ValueIterator(Iterator):
+    def __init__(self, *args, **kwargs):
+        super(ValueIterator, self).__init__(*args, **kwargs)
+
+        self.field_names = self.query.fields_select
+        self.fcount = len(self.field_names)
+        if not self.fcount:
+            raise ValueError("no select fields were set, so cannot iterate values")
+
+    def _get_result(self, d):
+        r = None
+        field_vals = [d.get(fn, None) for fn in self.field_names]
+        r = field_vals if self.fcount > 1 else field_vals[0]
+        return r
+
+
 class AllIterator(Iterator):
     """
     Similar to Iterator, but will chunk up results and make another query for the next
@@ -157,12 +169,24 @@ class Query(object):
     def __iter__(self):
         return self.get()
 
+    def select_field(self, field_name):
+        """set a field to be selected"""
+        return self.set_field(field_name, None)
+
+    def select_fields(self, *fields):
+        """set multiple fields to be selected"""
+        if fields:
+            if not isinstance(fields[0], types.StringTypes): 
+                fields = list(fields[0]) + list(fields)[1:]
+
+        for field_name in fields:
+            self.set_field(field_name)
+
     def set_field(self, field_name, field_val=None):
         """
         set a field into .fields attribute
 
-        this has a dual role, in select queries, these are the select fields, but in insert/update
-        queries, these are the fields that will be inserted/updated into the db
+        n insert/update queries, these are the fields that will be inserted/updated into the db
         """
         self.fields_set.append([field_name, field_val])
         return self
@@ -385,6 +409,16 @@ class Query(object):
 
         return field_vals
 
+    def pks(self, limit=None, page=None):
+        """convenience method for setting select_pk().values() since this is so common"""
+        self.fields_set = []
+        return self.select_pk().values(limit, page)
+
+    def pk(self):
+        """convenience method for setting select_pk().value() since this is so common"""
+        self.fields_set = []
+        return self.select_pk().value()
+
     def get_pks(self, field_vals):
         """convenience method for running in__id([...]).get() since this is so common"""
         field_name = self.orm.schema.pk
